[][src]Function polyline_ffi::drop_cstring

#[no_mangle]pub extern "C" fn drop_cstring(p: *mut c_char)

Free CString memory which Rust has allocated across the FFI boundary

Safety

This function is unsafe because it accesses a raw pointer which could contain arbitrary data