[−][src]Function polyline_ffi::drop_float_array
#[no_mangle]pub extern "C" fn drop_float_array(arr: Array)
Free Array memory which Rust has allocated across the FFI boundary
Safety
This function is unsafe because it accesses a raw pointer which could contain arbitrary data